﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using System.IO;
using ColorCode;
using SelectPdf;

namespace SelectPdf.Samples
{
    public partial class ConvertMultipleUrlsToPdf : Form
    {
        private void BtnCreatePdf_Click(object sender, EventArgs e)
        {
            Cursor = Cursors.WaitCursor;
            string file = "Document.pdf";

            try
            {
                /// read parameters from the webpage
                string url1 = TxtUrl1.Text;
                string url2 = TxtUrl2.Text;
                string url3 = TxtUrl3.Text;

                // create a new pdf document 
                PdfDocument doc = new PdfDocument();

                // add a new page to the document
                PdfPage page = doc.AddPage();

                // add the first url
                PdfHtmlElement html1 = new PdfHtmlElement(url1);
                PdfRenderingResult result = page.Add(html1);

                // get the last page of the previous conversion
                PdfPage page2 = doc.Pages[result.PdfPageLastIndex];

                // add the second url
                PdfHtmlElement html2 = new PdfHtmlElement(result.PdfPageLastRectangle.Left,
                    result.PdfPageLastRectangle.Bottom, url2);
                result = page2.Add(html2);

                // get the last page of the previous conversion
                PdfPage page3 = doc.Pages[result.PdfPageLastIndex];

                // add the third url
                PdfHtmlElement html3 = new PdfHtmlElement(result.PdfPageLastRectangle.Left,
                    result.PdfPageLastRectangle.Bottom, url3);
                result = page3.Add(html3);

                // save pdf document
                doc.Save(file);

                // close pdf document
                doc.Close();
            }
            catch (Exception ex)
            {
                MessageBox.Show(String.Format("Error: {0}", ex.Message),
                    "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                return;
            }
            finally
            {
                Cursor = Cursors.Arrow;
            }

            // open generated pdf
            try
            {
                System.Diagnostics.Process.Start(file);
            }
            catch
            {
                MessageBox.Show("Could not open generated pdf document",
                    "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }

        public ConvertMultipleUrlsToPdf()
        {
            InitializeComponent();

            try
            {
                // display highlighted sample code
                string code = File.ReadAllText(AppDomain.CurrentDomain.BaseDirectory +
                    "/../../" + "ConvertMultipleUrlsToPdf.cs");
                WBSampleCode.DocumentText = new CodeColorizer().Colorize(code, Languages.CSharp);
            }
            catch
            {
                WBSampleCode.DocumentText = "Sample code not available";
            }
        }

    }
}
