Imports System.Collections.Generic
Imports System.ComponentModel
Imports System.Data
Imports System.Drawing
Imports System.Linq
Imports System.Text
Imports System.Threading.Tasks
Imports System.Windows.Forms
Imports System.IO
Imports ColorCode
Imports SelectPdf

Namespace SelectPdf.Samples
    Partial Public Class HeadersAndFooters
        Inherits Form

        Private Sub BtnCreatePdf_Click(sender As Object, e As EventArgs) _
            Handles BtnCreatePdf.Click
            Cursor = Cursors.WaitCursor
            Dim file As String = "Document.pdf"

            Try
                ' create a new pdf document
                Dim doc As New PdfDocument()
                doc.Margins = New PdfMargins(10, 10, 0, 0)

                ' create a new pdf font
                Dim font As PdfFont = doc.AddFont(PdfStandardFont.Helvetica)
                font.Size = 24

                ' create a new pdf font
                Dim font2 As PdfFont = doc.AddFont(PdfStandardFont.Helvetica)
                font2.Size = 12
                font2.IsUnderline = True

                ' add a new page to the document
                Dim page As PdfPage = doc.AddPage()

                ' get image path
                Dim imgFile As String = AppDomain.CurrentDomain.BaseDirectory + _
                    "/../../files/logo.png"

                ' header template (100 points in height) with image element
                doc.Header = doc.AddTemplate(doc.Pages(0).ClientRectangle.Width, 100)
                Dim img1 As New PdfImageElement(0, 0, imgFile)
                doc.Header.Add(img1)

                ' footer template (100 points in height) with text element
                doc.Footer = doc.AddTemplate(doc.Pages(0).ClientRectangle.Width, 100)
                Dim text1 As New PdfTextElement(0, 50, _
                        "Footer text: Document generated by Select.Pdf", font2)
                text1.ForeColor = System.Drawing.Color.Blue
                doc.Footer.Add(text1)

                ' create a new text element and add it to the page if page elements are added 
                ' after header and footer is set, they will not be displayed in those areas.
                Dim text As New PdfTextElement(0, 0, Helper.SomeLongText(), font)
                page.Add(text)

                ' save pdf document
                doc.Save(file)

                ' close pdf document
                doc.Close()
            Catch ex As Exception
                MessageBox.Show([String].Format("Error: {0}", ex.Message), "Error", _
                                MessageBoxButtons.OK, MessageBoxIcon.[Error])
                Return
            Finally
                Cursor = Cursors.Arrow
            End Try

            ' open generated pdf
            Try
                System.Diagnostics.Process.Start(file)
            Catch
                MessageBox.Show("Could not open generated pdf document", "Error", _
                                MessageBoxButtons.OK, MessageBoxIcon.[Error])
            End Try
        End Sub

        Public Sub New()
            InitializeComponent()

            Try
                ' display highlighted sample code
                Dim code As String = File.ReadAllText(AppDomain.CurrentDomain.BaseDirectory + _
                                                      "/../../" + "HeadersAndFooters.vb")
                WBSampleCode.DocumentText = New CodeColorizer().Colorize(code, Languages.VbDotNet)
            Catch
                WBSampleCode.DocumentText = "Sample code not available"
            End Try
        End Sub

    End Class
End Namespace
